==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AStringConstant.h <==
// public final class soot.jimple.parser.node.AStringConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 81d517ef6337093d soot_jimple_parser_node_AStringConstant
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3f200529376bcdc9 soot_jimple_parser_node_PConstant

// header file dependencies
// @dep_header soot_jimple_parser_node_PConstant

#include "soot/jimple/parser/node/PConstant.h"

#ifndef _JC_soot_jimple_parser_node_AStringConstant_H_
#define _JC_soot_jimple_parser_node_AStringConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TStringConstant$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AStringConstant$sub_refs	_jc_soot_jimple_parser_node_AStringConstant$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs	_jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$refs	_jc_soot_jimple_parser_node_AStringConstant$refs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$nonrefs	_jc_soot_jimple_parser_node_AStringConstant$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$object	_jc_soot_jimple_parser_node_AStringConstant$object;

typedef const struct _jc_soot_jimple_parser_node_AStringConstant$vmethods	_jc_soot_jimple_parser_node_AStringConstant$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AStringConstant$vtable	_jc_soot_jimple_parser_node_AStringConstant$vtable;
typedef const struct _jc_soot_jimple_parser_node_AStringConstant$vtype	_jc_soot_jimple_parser_node_AStringConstant$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AStringConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *);
extern void _jc_soot_jimple_parser_node_AStringConstant$method$_init$c24aef728e352a36(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_TStringConstant$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AStringConstant$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AStringConstant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *);
extern struct _jc_soot_jimple_parser_node_TStringConstant$object *_jc_soot_jimple_parser_node_AStringConstant$method$getStringConstant$c0f166af0c0d90b0(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *);
extern void _jc_soot_jimple_parser_node_AStringConstant$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AStringConstant$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AStringConstant$method$setStringConstant$8480d6c2ab10fd54(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_TStringConstant$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AStringConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$getStringConstant$c0f166af0c0d90b0;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$setStringConstant$8480d6c2ab10fd54;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AStringConstant$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *);
	struct _jc_soot_jimple_parser_node_TStringConstant$object	*(*getStringConstant$c0f166af0c0d90b0)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setStringConstant$8480d6c2ab10fd54)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_TStringConstant$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AStringConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PConstant$vmethods	soot_jimple_parser_node_PConstant;
	_jc_soot_jimple_parser_node_AStringConstant$vmethods	soot_jimple_parser_node_AStringConstant;
};

// Vtype
struct _jc_soot_jimple_parser_node_AStringConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AStringConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStringConstant$sub_refs {
	struct _jc_soot_jimple_parser_node_TStringConstant$object	*__5fstringConstant__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStringConstant$refs {
    _jc_soot_jimple_parser_node_AStringConstant$sub_refs	soot_jimple_parser_node_AStringConstant;
    _jc_soot_jimple_parser_node_PConstant$sub_refs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStringConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PConstant$sub_nonrefs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs	soot_jimple_parser_node_AStringConstant;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AStringConstant$object {
	_jc_soot_jimple_parser_node_AStringConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AStringConstant$vtype	*vtype;
	_jc_soot_jimple_parser_node_AStringConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AStringConstant$vtype _jc_soot_jimple_parser_node_AStringConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AStringConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AStringConstant$class_object;

#endif	/* _JC_soot_jimple_parser_node_AStringConstant_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AStringConstant.h <==
// public final class soot.jimple.parser.node.AStringConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 81d517ef6337093d soot_jimple_parser_node_AStringConstant
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3f200529376bcdc9 soot_jimple_parser_node_PConstant

// header file dependencies
// @dep_header soot_jimple_parser_node_PConstant

#include "soot/jimple/parser/node/PConstant.h"

#ifndef _JC_soot_jimple_parser_node_AStringConstant_H_
#define _JC_soot_jimple_parser_node_AStringConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TStringConstant$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AStringConstant$sub_refs	_jc_soot_jimple_parser_node_AStringConstant$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs	_jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$refs	_jc_soot_jimple_parser_node_AStringConstant$refs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$nonrefs	_jc_soot_jimple_parser_node_AStringConstant$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AStringConstant$object	_jc_soot_jimple_parser_node_AStringConstant$object;

typedef const struct _jc_soot_jimple_parser_node_AStringConstant$vmethods	_jc_soot_jimple_parser_node_AStringConstant$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AStringConstant$vtable	_jc_soot_jimple_parser_node_AStringConstant$vtable;
typedef const struct _jc_soot_jimple_parser_node_AStringConstant$vtype	_jc_soot_jimple_parser_node_AStringConstant$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AStringConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStringConstant$method$_init$c24aef728e352a36(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_TStringConstant$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AStringConstant$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AStringConstant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TStringConstant$object *_jc_soot_jimple_parser_node_AStringConstant$method$getStringConstant$c0f166af0c0d90b0(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStringConstant$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStringConstant$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AStringConstant$method$setStringConstant$8480d6c2ab10fd54(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_TStringConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AStringConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$getStringConstant$c0f166af0c0d90b0;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$setStringConstant$8480d6c2ab10fd54;
extern _jc_method _jc_soot_jimple_parser_node_AStringConstant$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AStringConstant$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TStringConstant$object	*(*getStringConstant$c0f166af0c0d90b0)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setStringConstant$8480d6c2ab10fd54)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *, struct _jc_soot_jimple_parser_node_TStringConstant$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AStringConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AStringConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PConstant$vmethods	soot_jimple_parser_node_PConstant;
	_jc_soot_jimple_parser_node_AStringConstant$vmethods	soot_jimple_parser_node_AStringConstant;
};

// Vtype
struct _jc_soot_jimple_parser_node_AStringConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AStringConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStringConstant$sub_refs {
	struct _jc_soot_jimple_parser_node_TStringConstant$object	*__5fstringConstant__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStringConstant$refs {
    _jc_soot_jimple_parser_node_AStringConstant$sub_refs	soot_jimple_parser_node_AStringConstant;
    _jc_soot_jimple_parser_node_PConstant$sub_refs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AStringConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PConstant$sub_nonrefs	soot_jimple_parser_node_PConstant;
    _jc_soot_jimple_parser_node_AStringConstant$sub_nonrefs	soot_jimple_parser_node_AStringConstant;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AStringConstant$object {
	_jc_soot_jimple_parser_node_AStringConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AStringConstant$vtype	*vtype;
	_jc_soot_jimple_parser_node_AStringConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AStringConstant$vtype _jc_soot_jimple_parser_node_AStringConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AStringConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AStringConstant$class_object;

#endif	/* _JC_soot_jimple_parser_node_AStringConstant_H_ */
